@@ -455,10 +455,13 @@ public:
 		else {
 			timeSupply = getTimeNextSupplyDone();
 		}
-		if (executor == NULL)timeQueue = 0;
-		else {
+		if (executor > 0) {
 			timeQueue = entityList[executor].timeQueueFree - time;
 		}
+		else {
+			timeQueue = 0;
+			
+		}
 		double largest = timeMinerals;
 		if (timeGas > largest) largest = timeGas;
 		if (timeSupply > largest) largest = timeSupply;
@@ -534,7 +537,7 @@ public:
 		gas -= a.gasCost;
 		supply += a.supCost;
 		entityList.push_back(loadEntity(action, executor, target, false));
-		if (executor != NULL) {
+		if (executor > 0) {
 			entityList[executor].timeQueueFree = a.duration + time;
 			entityList[executor].child = entityList.size() - 1;
 		}
@@ -650,6 +653,19 @@ public:
 		}
 		return returnState;
 	}
+
+	int pickNextExecutor(vector<int> viableExecutors) {
+		if (viableExecutors.size() == 0) return NULL;
+		double timeFree = 10000;
+		int nextExecutor = 0;
+		for (int x : viableExecutors) {
+			if (entityList[x].timeQueueFree < timeFree) {
+				timeFree = entityList[x].timeQueueFree;
+				nextExecutor = x;
+			}
+		}
+		return nextExecutor;
+	}
 };
 
 
@@ -675,6 +691,7 @@ PYBIND11_MODULE(probotest1, m) {
 		.def("getViableActions", &ProtossMacroEnv::getViableActions)
 		.def("getViableExecutors", &ProtossMacroEnv::getViableExecutors)
 		.def("getViableTargets", &ProtossMacroEnv::getState)
+		.def("pickNextExecutor", &ProtossMacroEnv::pickNextExecutor)
         .def_readwrite("minerals", &ProtossMacroEnv::minerals)
 		.def_readwrite("gas", &ProtossMacroEnv::gas)
 		.def_readwrite("time", &ProtossMacroEnv::time)
